library(repeated)
library(growth)

y <- read.list("azams.dat",order=2:1)
dose <- read.list("azadose.dat",order=2:1)
treat <- cbind(c(rep(0,17),rep(1,15),rep(0,16)),c(rep(0,32),rep(1,16)))
colnames(treat) <- c("AZ + P","AZ + MP")
resp <- restovec(y)

if(interactive()){
postscript(file="azamsr.eps")
par(mfrow=c(3,1))
plot(y[[1]][,2],y[[1]][,1],type="l",xlim=c(-200,1400),ylim=c(0,1200),
	xlab="",ylab="AFCR level")
for(i in 2:17)lines(y[[i]][,2],y[[i]][,1])
text(800,1000,"P + P")
plot(y[[18]][,2],y[[18]][,1],type="l",xlim=c(-200,1400),ylim=c(0,1200),
	xlab="",ylab="AFCR level")
for(i in 19:32)lines(y[[i]][,2],y[[i]][,1])
text(800,1000,"AZ + P")
plot(y[[33]][,2],y[[33]][,1],type="l",xlim=c(-200,1400),ylim=c(0,1200),
	xlab="Days from start of treatment",ylab="AFCR level")
for(i in 34:48)lines(y[[i]][,2],y[[i]][,1])
text(800,1000,"AZ + MP")
postscript(file="azamsd.eps")
par(mfrow=c(3,1))
dx <- as.vector(matrix(rep(dose[[1]][,2],2),nrow=2,byrow=T))
dy <- c(0,as.vector(matrix(rep(dose[[1]][,1],2),nrow=2,byrow=T)))
dy <- dy[1:(length(dy)-1)]
plot(dx,dy,type="l",xlim=c(-200,1400),ylim=c(0,3),xlab="",ylab="Dose")
for(i in 2:17){
	dx <- as.vector(matrix(rep(dose[[i]][,2],2),nrow=2,byrow=T))
	dy <- c(0,as.vector(matrix(rep(dose[[i]][,1],2),nrow=2,byrow=T)))
	dy <- dy[1:(length(dy)-1)]
	lines(dx,dy)}
text(1000,2.9,"P + P")
dx <- as.vector(matrix(rep(dose[[18]][,2],2),nrow=2,byrow=T))
dy <- c(0,as.vector(matrix(rep(dose[[18]][,1],2),nrow=2,byrow=T)))
dy <- dy[1:(length(dy)-1)]
plot(dx,dy,type="l",xlim=c(-200,1400),ylim=c(0,3),xlab="",ylab="Dose")
for(i in 19:32){
	dx <- as.vector(matrix(rep(dose[[i]][,2],2),nrow=2,byrow=T))
	dy <- c(0,as.vector(matrix(rep(dose[[i]][,1],2),nrow=2,byrow=T)))
	dy <- dy[1:(length(dy)-1)]
	lines(dx,dy)}
text(1000,2.9,"AZ + P")
dx <- as.vector(matrix(rep(dose[[33]][,2],2),nrow=2,byrow=T))
dy <- c(0,as.vector(matrix(rep(dose[[33]][,1],2),nrow=2,byrow=T)))
dy <- dy[1:(length(dy)-1)]
plot(dx,dy,type="l",xlim=c(-200,1400),ylim=c(0,3),
	xlab="Days from start of treatment",ylab="Dose")
for(i in 34:48){
	dx <- as.vector(matrix(rep(dose[[i]][,2],2),nrow=2,byrow=T))
	dy <- c(0,as.vector(matrix(rep(dose[[i]][,1],2),nrow=2,byrow=T)))
	dy <- dy[1:(length(dy)-1)]
	lines(dx,dy)}
text(1000,2.9,"AZ + MP")
}

print(u <- carma(resp))
print(u0 <- carma(resp,trans="sqrt"))
print(u0re <- carma(resp,pre=0.8,pos=c(1,1),trans="sqrt"))
print(u0ar <- carma(resp,arma=c(1,0,0),par=-3,trans="sqrt"))
print(u0ra <- carma(resp,pre=0.8,pos=c(1,1),arma=c(1,0,0),par=-3,trans="sqrt"))
print(u1 <- carma(resp,torder=1,trans="sqrt"))
print(u1re <- carma(resp,torder=1,pre=0.8,pos=c(1,1),trans="sqrt"))
print(u1ar <- carma(resp,torder=1,arma=c(1,0,0),par=1,trans="sqrt"))
print(u1ra <- carma(resp,torder=1,pre=0.8,pos=c(1,1),arma=c(1,0,0),
	par=-2,trans="sqrt"))
print(u1t <- carma(resp,torder=1,ccov=treat,trans="sqrt"))
print(u1ret <- carma(resp,torder=1,ccov=treat,pre=0.8,pos=c(1,1),trans="sqrt"))
print(u1art <- carma(resp,torder=1,ccov=treat,arma=c(1,0,0),par=-3,
	trans="sqrt"))
print(u1rat <- carma(resp,torder=1,ccov=treat,pre=0.8,pos=c(1,1),
	arma=c(1,0,0),par=-2.5,trans="sqrt"))
print(u1i <- carma(resp,torder=1,ccov=treat,interact=c(1,1),trans="sqrt"))
print(u1rei <- carma(resp,torder=1,ccov=treat,interact=c(1,1),pre=0.8,
	pos=c(1,1),trans="sqrt"))
print(u1ari <- carma(resp,torder=1,ccov=treat,interact=c(1,1),arma=c(1,0,0),
	par=-3,trans="sqrt"))
print(u1rai <- carma(resp,torder=1,ccov=treat,interact=c(1,1),pre=0.8,
	pos=c(1,1),arma=c(1,0,0),par=-2.5,trans="sqrt"))
print(u2 <- carma(resp,torder=2,trans="sqrt"))
print(u2re <- carma(resp,torder=2,pre=0.8,pos=c(1,1),trans="sqrt"))
print(u2ar <- carma(resp,torder=2,arma=c(1,0,0),par=1,trans="sqrt"))
print(u2ra <- carma(resp,torder=2,pre=0.8,pos=c(1,1),arma=c(1,0,0),
	par=-2,trans="sqrt"))
print(u2t <- carma(resp,torder=2,ccov=treat,trans="sqrt"))
print(u2ret <- carma(resp,torder=2,ccov=treat,pre=0.8,pos=c(1,1),trans="sqrt"))
print(u2art <- carma(resp,torder=2,ccov=treat,arma=c(1,0,0),par=1,
	trans="sqrt"))
print(u2rat <- carma(resp,torder=2,ccov=treat,pre=0.8,pos=c(1,1),
	arma=c(1,0,0),par=-2,trans="sqrt"))
print(u2i <- carma(resp,torder=2,ccov=treat,interact=c(2,2),trans="sqrt"))
print(u2rei <- carma(resp,torder=2,ccov=treat,interact=c(2,2),pre=0.8,
	pos=c(1,1),trans="sqrt"))
print(u2ari <- carma(resp,torder=2,ccov=treat,interact=c(2,2),arma=c(1,0,0),
	par=-2,trans="sqrt"))
print(u2rai <- carma(resp,torder=2,ccov=treat,interact=c(2,2),pre=0.8,
	pos=c(1,1),arma=c(1,0,0),par=-2,trans="sqrt"))
print(u <- carma(resp,torder=3,trans="sqrt"))

tvc1 <- list()
for(i in y) tvc1 <- c(tvc1,list(matrix((i[,2]-501.4581)/100,ncol=1)))
tvc1 <- tvctomat(tvc1,names="t^1")
tvc2 <- list()
for(i in y) tvc2 <- c(tvc2,list(cbind((i[,2]-501.4581)/100,
	(i[,2]-501.4581)^2/10000)))
tvc2 <- tvctomat(tvc2,names= c("t^1","t^2"))
tvc1i <- tvctomat(tvc1,names="AZ+P",interaction=1,ccov=treat[,1])
tvc1i <- tvctomat(tvc1i,names="AZ+MP",interaction=1,ccov=treat[,2])
tvc2i <- tvctomat(tvc2,names="AZ+P",interaction=1,ccov=treat[,1])
tvc2i <- tvctomat(tvc2i,names="AZ+MP",interaction=1,ccov=treat[,2])
tvc2i <- tvctomat(tvc2i,names="AZ+P",interaction=2,ccov=treat[,1])
tvc2i <- tvctomat(tvc2i,names="AZ+MP",interaction=2,ccov=treat[,2])
tvc0d <- gettvc(y,tvcov=dose,ties=F)
tvc1d <- gettvc(y,tvcov=dose,oldtvc=tvc1,ties=F)
tvc2d <- gettvc(y,tvcov=dose,oldtvc=tvc2,ties=F)
tvc2dt <- tvctomat(tvc0d,names="AZ+P",interaction="dose",ccov=treat[,1])
tvc2dt <- tvctomat(tvc2dt,names="AZ+MP",interaction="dose",ccov=treat[,2])
tvc2dt <- tvctomat(tvc2dt,old=tvc2i)

kalseries(resp,intensity="normal",dep="independence",pinit=0.44,preg=160,
 	psh=20000)
print(k0 <- kalseries(resp,intensity="normal",dep="independence",
	preg=13,psh=35,trans="sqrt"))
print(k0ar <- kalseries(resp,intensity="normal",dep="serial",pinit=0.96,
	pdep=0.999,preg=9,psh=10.4,trans="sqrt"))
print(k0re <- kalseries(resp,intensity="normal",dep="frailty",pdep=0.5,
	preg=12,psh=26,trans="sqrt"))
print(k0art <- kalseries(resp,intensity="normal",dep="serial",pinit=0.86,
	pdep=0.99,psh=7.2,preg=c(13,-6.2,-5.45),ccov=treat,trans="sqrt"))
print(k0arts <- kalseries(resp,intensity="normal",dep="serial",pinit=0.86,
	pdep=0.99,psh=6.8,preg=c(167,-124.5,-109),ccov=treat,
	trans="sqrt",link="square"))
print(k1art <- kalseries(resp,intensity="normal",dep="serial",pinit=0.58,
	pdep=0.994,psh=9.8,preg=c(14.1,-5.76,-4.8),ccov=treat,ptvc=-0.4,
	tvc=tvc1,trans="sqrt"))
print(k2art <- kalseries(resp,intensity="normal",dep="serial",pinit=0.49,
	pdep=0.996,psh=9.9,preg=c(12,-4.86,-3.92),ccov=treat,
	ptvc=c(-0.67,0.1),tvc=tvc2,trans="sqrt"))
print(k1artd <- kalseries(resp,intensity="normal",dep="serial",pinit=0.57,
	pdep=0.993,psh=9.6,preg=c(14,-5.7,-4.8),ccov=treat,
	ptvc=c(-0.44,-0.047),tvc=tvc1d,trans="sqrt"))
print(k1arti <- kalseries(resp,intensity="normal",dep="serial",pinit=0.64,
	pdep=0.992,psh=8.6,preg=c(14.1,-5.8,-4.83),ccov=treat,
	ptvc=c(-0.44,0.02,-0.02),tvc=tvc1i,trans="sqrt"))
print(k2arti <- kalseries(resp,intensity="normal",dep="serial",pinit=0.46,
	pdep=0.997,psh=9.2,preg=c(13.1,-6.55,-5.95),ccov=treat,
	ptvc=c(-0.32,0.038,-0.61,-0.64,0.1,0.12),tvc=tvc2i,trans="sqrt"))
print(k1ret <- kalseries(resp,intensity="normal",dep="frailty",pinit=0.58,
	psh=10.5,preg=c(14.1,-5.76,-4.8),ccov=treat,ptvc=0,
	tvc=tvc1,trans="sqrt"))
print(k2ret <- kalseries(resp,intensity="normal",dep="frailty",pinit=0.58,
	psh=10.5,preg=c(14.1,-5.76,-4.8),ccov=treat,ptvc=c(0,0),
	tvc=tvc2,trans="sqrt"))

rsp <- function(y,p) (p[1]+p[2]*y+p[3]*y^2)^2
if(interactive()){
postscript(file="azamprof.eps",width=5,height=5)
plot(seq(-200,1400,by=100),
	rsp(seq(-200,1400,by=100)-u2rai$ave,u2rai$beta[1:3]),type="l",
	xlim=c(-200,1400),ylim=c(0,1200),xlab="Days from start of treatment",
	ylab="AFCR level")
lines(seq(-200,1400,by=100),
	rsp(seq(-200,1400,by=100)-u2rai$ave,u2rai$beta[1:3]+u2rai$beta[4:6]),
	lty="2")
lines(seq(-200,1400,by=100),
	rsp(seq(-200,1400,by=100)-u2rai$ave,u2rai$beta[1:3]+u2rai$beta[7:9]),
	lty="3")
legend(800,1000,legend=c("P + P","AZ + P","AZ + MP"),lty=1:3,bty="n")
}

print(z0 <- elliptic(resp,preg=c(5.734,4.628,1.716,-1.497),pvar=26.4,
	trans="sqrt",link="square",model="logistic"))
print(z0re <- elliptic(resp,preg=c(5.734,4.628,1.716,-1.497),pvar=26.4,pre=7.4,
	trans="sqrt",link="square",model="logistic"))
print(z0ar <- elliptic(resp,preg=c(5.765,4.66,13,-3.9),pvar=30.7,
	par=0.98,trans="sqrt",link="square",model="logistic"))
print(z0ra <- elliptic(resp,preg=c(5.734,4.63,19,-5),pvar=14.7,pre=12,
	par=0.87,trans="sqrt",link="square",model="logistic"))

print(z1 <- elliptic(resp,preg=c(5.72,5.06,1.52,-1.56,-0.048,-1.12,
	0.005,-0.02,0.11,-0.76,0.081,0.018),
	pvar=20,ccov=treat,trans="sqrt",link="square",model="logistic"))
print(z1re <- elliptic(resp,preg=c(5.72,5.2,2.6,-2,-0.05,-1.2,
	-0.02,-2.3,0.08,-0.86,2.2,-2),pvar=13.36,pre=6.54,
	ccov=treat,trans="sqrt",link="square",model="logistic",iter=200))
print(z1ar <- elliptic(resp,preg=c(5.8,5.1,2,-2,-0.06,-1.2,
	0.003,-0.2,0.08,-0.85,-0.12,-1.6),pvar=20,par=0.92,
	ccov=treat,trans="sqrt",link="square",model="logistic",iter=200))
print(z1ra <- elliptic(resp,preg=c(5.72,5.2,2.6,-2,-0.05,-1.2,
	-0.02,-2.3,0.08,-0.86,2.2,-2),model="logistic",iter=200,
	pvar=4.3,pre=6.5,par=0.9,ccov=treat,trans="sqrt",link="square"))

rsp <- function(y,p){
	y0 <- exp(p[1])
	yinf <- exp(p[2])
	yinf*(1+((yinf/y0)^p[4]-1)*exp(-yinf^p[4]*exp(p[3])*y))^(-1/p[4])}
if(interactive()){
postscript(file="azamspr2.eps",width=5,height=5)
plot(seq(-200,1400,by=100),
	rsp(seq(-200,1400,by=100),z1ra$coef[1:4]),type="l",
	xlim=c(-200,1400),ylim=c(0,1200),xlab="Days from start of treatment",
	ylab="AFCR level")
lines(seq(-200,1400,by=100),
	rsp(seq(-200,1400,by=100),z1ra$coef[1:4]+z1ra$coef[5:8]),
	lty="2")
lines(seq(-200,1400,by=100),
	rsp(seq(-200,1400,by=100),z1ra$coef[1:4]+z1ra$coef[9:12]),
	lty="3")
legend(800,1000,legend=c("P + P","AZ + P","AZ + MP"),lty=1:3,bty="n")
}

print(z2 <- elliptic(resp,tvcov=tvc0d,preg=c(5.59,-10.46,1.41,8.6),pvar=27.5,
 	trans="sqrt",link="square",model="logistic"))
print(z2re <- elliptic(resp,tvcov=tvc0d,preg=c(5.58,-14,1.6,7.55),
	pvar=15.5,pre=11.7,trans="sqrt",link="square",model="logistic"))
print(z2ar <- elliptic(resp,tvcov=tvc0d,preg=c(5.54,-13.6,1.5,7.7),
	pvar=31.9,par=0.99,trans="sqrt",link="square",model="logistic"))
print(z2ra <- elliptic(resp,tvcov=tvc0d,preg=c(5.54,1.3,-1.3,0.85),
	pvar=15.9,pre=14.7,par=0.02,trans="sqrt",link="square",
	model="logistic"))

print(z3 <- elliptic(resp,tvcov=tvc0d,preg=c(5.608,6.15,-2.41,.4030,1.579,
	1.153),pvar=21.7,ccov=treat,trans="sqrt",link="square",
	model="logistic"))
print(z3re <- elliptic(resp,tvcov=tvc0d,preg=c(5.617,-.2980,-1.129,
	.4540,1.667,1.403),pvar=13.4,pre=8,ccov=treat,trans="sqrt",
	link="square",model="logistic"))
print(z3reel <- elliptic(resp,tvcov=tvc0d,preg=c(5.617,-.2980,-1.129,
	.4540,1.667,1.403),pvar=13.4,pre=8,ccov=treat,trans="sqrt",
	link="square",model="logistic",pell=1))
print(z3ar <- elliptic(resp,tvcov=tvc0d,preg=c(5.583,5.866,-2.367,
	.3820,1,1.141),pvar=24,par=0.5,ccov=treat,trans="sqrt",
	link="square",model="logistic"))
print(z3ra <- elliptic(resp,tvcov=tvc0d,preg=c(5.6,1.9,-1.5,
	.43,1.5,1.36),pvar=13.4,par=0.9,pre=8.2,ccov=treat,trans="sqrt",
	link="square",model="logistic"))

# Heitjan's linear model
v <- as.vector(covariates(tvc0d))
trt <- treat[covind(resp),]
mu <- function(p) p[1]+p[2]*v+p[3]*(v>0)
print(s0 <- elliptic(resp,preg=c(10.6,0,0),pvar=14.7,trans="sqrt",model=mu))
print(s0re <- elliptic(resp,preg=c(10.6,0,0),pvar=14.7,pre=11,
	trans="sqrt",model=mu))
print(s0ar <- elliptic(resp,preg=c(13,0.1,-3),pvar=36,par=0.98,
	trans="sqrt",model=mu))
print(s0ra <- elliptic(resp,preg=c(10.6,0,0),pvar=4,pre=5,par=0.9,
	trans="sqrt",model=mu))
mu <- function(p) p[1]+p[2]*v+p[3]*(v>0)+(p[4]*v+p[5]*(v>0))*trt[,1]+
	+(p[6]*v+p[7]*(v>0))*trt[,2]
print(s0t <- elliptic(resp,preg=c(10.6,0,0,0,0,0,0),pvar=14.7,
	ccov=treat,trans="sqrt",model=mu))
print(s0ret <- elliptic(resp,preg=c(15,-2.2,4.3,0.6,-8.4,-0.4,-4.5),pvar=14.7,
	pre=11,ccov=treat,trans="sqrt",model=mu))
print(s0art <- elliptic(resp,preg=c(15,-2.2,4.3,0.6,-8.4,-0.4,-4.5),pvar=18,
	par=0.9,ccov=treat,trans="sqrt",model=mu))
print(s0rat <- elliptic(resp,preg=c(14,-1.6,4.3,0.4,-7.8,-0.3,-5.3),pvar=18,
	pre=8,par=0.9,ccov=treat,trans="sqrt",model=mu))

print(v0 <- elliptic(resp,pvar=12.7,trans="sqrt",model="linear",torder=2))
#print(v0 <- elliptic(resp,pvar=12.7,tvcov=tvc2,trans="sqrt",model="linear"))
print(v0re <- elliptic(resp,pvar=26,trans="sqrt",model="linear",torder=2,
	pre=11))
print(v0ar <- elliptic(resp,pvar=26,trans="sqrt",model="linear",torder=2,
	par=0.8))
print(v0ra <- elliptic(resp,pvar=26,trans="sqrt",model="linear",torder=2,
	par=0.9,pre=11))

print(v0t <- elliptic(resp,pvar=12.7,ccov=treat,
	trans="sqrt",model="linear",torder=2))
print(v0ret <- elliptic(resp,pvar=12.7,ccov=treat,
	trans="sqrt",model="linear",torder=2,pre=11))
print(v0art <- elliptic(resp,pvar=12.7,ccov=treat,
	trans="sqrt",model="linear",torder=2,par=0.9))
print(v0rat <- elliptic(resp,pvar=12.7,ccov=treat,
	trans="sqrt",model="linear",torder=2,pre=6,par=0.9))

print(v0i <- elliptic(resp,pvar=17.7,ccov=treat,inter=c(2,2),
	trans="sqrt",model="linear",torder=2))
print(v0rei <- elliptic(resp,pvar=17.7,ccov=treat,inter=c(2,2),
	trans="sqrt",model="linear",torder=2,pre=6))
print(v0ari <- elliptic(resp,pvar=17.7,ccov=treat,inter=c(2,2),
	trans="sqrt",model="linear",torder=2,par=0.9))
print(v0rai <- elliptic(resp,pvar=17.7,ccov=treat,inter=c(2,2),
	trans="sqrt",model="linear",torder=2,pre=6,par=0.4))

print(v1 <- elliptic(resp,pvar=20,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2))
print(v1re <- elliptic(resp,pvar=20,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,pre=15))
print(v1ar <- elliptic(resp,pvar=20,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,par=0.5))
print(v1ra <- elliptic(resp,pvar=20,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,pre=11,par=0.8))

print(v1t <- elliptic(resp,pvar=15,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2))
print(v1ret <- elliptic(resp,pvar=13.4,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,pre=6.3))
print(v1art <- elliptic(resp,pvar=13.4,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,par=0.9))
print(v1rat <- elliptic(resp,pvar=13.4,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,pre=6.3,par=0.9))

print(v1i <- elliptic(resp,pvar=12.7,ccov=treat,inter=c(2,2),tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2))
print(v1rei <- elliptic(resp,pvar=12.7,ccov=treat,inter=c(2,2),tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,pre=6.3))
print(v1ari <- elliptic(resp,pvar=12.7,ccov=treat,inter=c(2,2),tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,par=0.9))
print(v1rai <- elliptic(resp,pvar=12.7,ccov=treat,inter=c(2,2),tvcov=tvc0d,
	trans="sqrt",model="linear",torder=2,pre=6.3,par=0.9))

tt <- (times(resp)-501.4581)/100
nobs <- nobs(resp)
trt1 <- treat[rep(1:length(nobs),nobs),1]
trt2 <- treat[rep(1:length(nobs),nobs),2]
mu <- function(p) {
	p[1]+p[2]*tt+p[3]*tt^2+(p[4]+p[5]*tt+p[6]*tt^2)*trt1+
	(p[7]+p[8]*tt+p[9]*tt^2)*trt2+v*p[10]}
print(r1rai <- elliptic(resp,preg=c(15.56,-0.32,0.022,-7.52,-0.6,0.113,-6,
	-0.59,0.111,-0.49),pvar=13.1,pre=6.4,par=0.81,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model=mu,torder=1))
mu <- function(p) {
	p[1]+p[2]*tt+p[3]*tt^2+(p[4]+p[5]*tt+p[6]*tt^2)*trt1+
	(p[7]+p[8]*tt+p[9]*tt^2)*trt2+v*(p[10]+p[11]*trt1+p[12]*trt2)}
print(r1di <- elliptic(resp,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model=mu,torder=1))
print(r1redi <- elliptic(resp,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,pre=6.4,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model=mu,torder=1))
print(r1ardi <- elliptic(resp,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,par=0.81,ccov=treat,tvcov=tvc0d,
	trans="sqrt",model=mu,torder=1))
print(r1radi <- elliptic(resp,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,pre=6.4,par=0.81,ccov=treat,
	tvcov=tvc0d,trans="sqrt",model=mu,torder=1))

print(r1el <- elliptic(resp,preg=c(13.08,-0.44,0.057,-3.48,-0.38,0.051,-3.49,
	-0.48,0.074,0.54,-2.24,-1.39),pvar=0.8,ccov=treat,
	tvcov=tvc0d,trans="sqrt",model=mu,torder=1,pell=0.6))
print(r1arel <- elliptic(resp,preg=c(13.08,-0.44,0.057,-3.48,-0.38,0.051,-3.49,
	-0.48,0.074,0.54,-2.24,-1.39),pvar=0.8,par=0.79,ccov=treat,
	tvcov=tvc0d,trans="sqrt",model=mu,torder=1,pell=0.6))
print(r1reel <- elliptic(resp,preg=c(13.08,-0.44,0.057,-3.48,-0.38,0.051,-3.49,
	-0.48,0.074,0.54,-2.24,-1.39),pvar=0.8,pre=0.35,ccov=treat,
	tvcov=tvc0d,trans="sqrt",model=mu,torder=1,pell=0.6))
print(r1radiel <- elliptic(resp,preg=c(13.08,-0.44,0.057,-3.48,-0.38,0.051,
	-3.49,-0.48,0.074,0.54,-2.24,-1.39),pvar=0.8,pre=0.35,par=0.79,
	ccov=treat,tvcov=tvc0d,trans="sqrt",model=mu,torder=1,pell=0.6))

mu <- function(p) {
	p[1]+p[2]*tt+p[3]*tt^2+(p[4]+p[5]*tt+p[6]*tt^2)*trt1+
	(p[7]+p[8]*tt+p[9]*tt^2)*trt2+v*(p[10]+p[11]*trt1+p[12]*trt2)+
	p[13]*(v>0)}
print(r1raddi <- elliptic(resp,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4,0),pvar=12.9,pre=6.4,par=0.8,ccov=treat,
	tvcov=tvc0d,trans="sqrt",model=mu,torder=1))
mu <- function(p) {
	p[1]+p[2]*tt+p[3]*tt^2+(p[4]+p[5]*tt+p[6]*tt^2)*trt1+
	(p[7]+p[8]*tt+p[9]*tt^2)*trt2+v*(p[10]+p[11]*trt1+p[12]*trt2)+
	(p[13]+p[14]*trt1+p[15]*trt2)*(v>0)}
print(r1raddi2 <- elliptic(resp,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4,0.77,0,0),pvar=12.9,pre=6.5,par=0.79,
	ccov=treat,tvcov=tvc0d,trans="sqrt",model=mu,torder=1))

print(k2retd <- kalseries(resp,intensity="normal",dep="frailty",pinit=0.35,
	psh=10.68,preg=c(11.93,-2.42,-2.6),ccov=treat,tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.47,0.066,-0.32,-0.4,0.041,0.062,0.72,-2.45,-1.94),iter=200))
print(k2artd <- kalseries(resp,intensity="normal",dep="serial",pinit=0.478,
	pdep=0.999,psh=8.81,preg=c(11.4,-2.37,-2.89),ccov=treat,
	tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.416,0.065,-0.388,-0.454,0.034,0.07,0.74,-2.35,-1.66)))
print(k2mtd <- kalseries(resp,intensity="normal",dep="Markov",pinit=0.272,
	pdep=0.998,psh=8.81,preg=c(13.962,-2.573,-2.239),ccov=treat,
	tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.29,0.0559,-0.305,-0.391,0.0232,0.0608,1.139,-2.448,-1.88)))

if(interactive()){
postscript(file="azamipr.eps")
par(mfrow=c(3,1),font.main=1)
plot(x=0,y=0,type="n",main="Placebos",xlim=c(-200,1400),ylim=c(0,1200),
	xlab="",ylab="AFCR")
plot(iprofile(k2artd),add=T)
#plot(iprofile(k2artd),nind=2,add=T,lty=2,pch=1)
plot(iprofile(k2artd),nind=17,add=T,lty=3,pch=2)
plot(x=0,y=0,type="n",main="Azathioprine + placebo",
	xlab="",ylab="AFCR",xlim=c(-200,1400),ylim=c(0,1200))
plot(iprofile(k2artd),nind=18,add=T)
#plot(iprofile(k2artd),nind=19,add=T,lty=2,pch=1)
plot(iprofile(k2artd),nind=32,add=T,lty=3,pch=2)
plot(x=0,y=0,type="n",main="Azathioprine + methylprednisolone",
	xlab="Days",ylab="AFCR",xlim=c(-200,1400),ylim=c(0,1200))
plot(iprofile(k2artd),nind=33,add=T)
#plot(iprofile(k2artd),nind=34,add=T,lty=2,pch=1)
plot(iprofile(k2artd),nind=48,add=T,lty=3,pch=2)
}

print(kl2retd <- kalseries(resp,intensity="logistic",dep="frailty",pinit=0.28,
	psh=3.57,preg=c(12.25,-2.86,-2.82),ccov=treat,tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.48,0.067,-0.32,-0.42,0.04,0.064,0.72,-2.44,-1.91)))
print(kl2artd <- kalseries(resp,intensity="logistic",dep="serial",pinit=0.35,
	pdep=0.998,psh=3.27,preg=c(12.08,-2.8,-2.84),ccov=treat,
	tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.47,0.066,-0.35,-0.44,0.037,0.067,0.76,-2.45,-1.89)))
print(kl2mtd <- kalseries(resp,intensity="logistic",dep="Markov",pinit=0.153,
	pdep=0.998,psh=5.43,preg=c(13.206,-2.774,-2.467),ccov=treat,
	tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.379,0.0603,-0.315,-0.408,0.0284,0.068,1.068,-2.45,-1.866)))

print(kc2retd <- kalseries(resp,intensity="Cauchy",dep="frailty",pinit=0.16,
	psh=4.93,preg=c(12.78,-3.61,-2.84),ccov=treat,tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.55,0.073,-0.32,-0.41,0.036,0.064,0.72,-2.44,-2.08)))
print(kc2artd <- kalseries(resp,intensity="Cauchy",dep="serial",pinit=0.16,
	pdep=0.99,psh=4.92,preg=c(13.2,-3.75,-3.27),ccov=treat,
	tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.53,0.066,-0.33,-0.45,0.039,0.072,0.53,-2.45,-1.89)))
print(kc2mtd <- kalseries(resp,intensity="Cauchy",dep="Markov",pinit=0.004,
	pdep=0.997,psh=5.626,preg=c(12.513,-3.448,-2.977),ccov=treat,
	tvc=tvc2dt,trans="sqrt",
	ptvc=c(-0.53,0.0696,-0.35,-0.455,0.0343,0.0725,0.679,-2.446,-1.888)))

yy <- y
for(i in 1:48)for(j in 1:dim(yy[[i]])[1])
	yy[[i]][j,1] <- ifelse(yy[[i]][j,1]==0,0.001,yy[[i]][j,1])
yy <- restovec(yy)

print(kw2artd <- kalseries(yy,intensity="Weibull",dep="serial",pinit=0.86,
	pdep=0.993,psh=2,preg=c(3.88,0.42,0.54),ccov=treat,
	tvc=tvc2dt,link="log",
	ptvc=c(-0.14,0.031,-0.028,-0.036,-0.013,-0.009,0.57,-0.93,-0.81)))

print(kg2artd <- kalseries(yy,intensity="gamma",dep="serial",pinit=0.4,
	pdep=0.998,psh=2.2,preg=c(3.74,-0.065,0),ccov=treat,
	tvc=tvc2dt,link="log",
	ptvc=c(-0.12,0.02,-0.033,-0.038,-0.003,0,0.54,-0.94,-0.82)))

print(kln2artd <- kalseries(yy,intensity="log normal",dep="serial",pinit=0.93,
	pdep=0.993,psh=2,preg=c(3.81,0.49,0.62),ccov=treat,
	tvc=tvc2dt,
	ptvc=c(-0.14,0.033,-0.022,-0.026,-0.016,-0.014,0.57,-0.94,-0.82)))

print(kll2artd <- kalseries(yy,intensity="log logistic",dep="serial",
	pinit=0.93,pdep=0.999,psh=2,preg=c(3.81,0.49,0.62),ccov=treat,
	tvc=tvc2dt,
	ptvc=c(-0.14,0.033,-0.022,-0.026,-0.016,-0.014,0.57,-0.94,-0.82)))
