library(repeated)
library(growth)

y <- read.list("azams.dat",order=2:1)
dose <- read.list("azadose.dat",order=2:1)
treat <- cbind(c(rep(0,17),rep(1,15),rep(0,16)),c(rep(0,32),rep(1,16)))
colnames(treat) <- c("AZP","AZMP")
resp <- restovec(y)

if(interactive()){
postscript(file="azamsr.eps",height=7,width=5)
par(mfrow=c(3,1),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(resp,nind=1:17,xlim=c(-200,1400),ylim=c(0,1200),xlab="",ylab="AFCR level",
	lty=1,main="P + P",yaxt="n")
axis(2,at=c(0,400,800,1200))
plot(resp,nind=18:32,xlim=c(-200,1400),ylim=c(0,1200),xlab="",
	ylab="AFCR level",lty=1,main="AZ + P",yaxt="n")
axis(2,at=c(0,400,800,1200))
plot(resp,nind=33:48,xlim=c(-200,1400),ylim=c(0,1200),ylab="AFCR level",
	xlab="Days from start of treatment",lty=1,main="AZ + MP",yaxt="n")
axis(2,at=c(0,400,800,1200))
dev.off()
postscript(file="azamsd.eps",height=7,width=5)
par(mfrow=c(3,1),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
dx <- as.vector(matrix(rep(dose[[1]][,2],2),nrow=2,byrow=T))
dy <- c(0,as.vector(matrix(rep(dose[[1]][,1],2),nrow=2,byrow=T)))
dy <- dy[1:(length(dy)-1)]
plot(dx,dy,type="l",xlim=c(-200,1400),ylim=c(0,3),xlab="",ylab="Dose",
	main="P + P",yaxt="n")
axis(2,at=c(0,1,2,3))
for(i in 2:17){
	dx <- as.vector(matrix(rep(dose[[i]][,2],2),nrow=2,byrow=T))
	dy <- c(0,as.vector(matrix(rep(dose[[i]][,1],2),nrow=2,byrow=T)))
	dy <- dy[1:(length(dy)-1)]
	lines(dx,dy)}
dx <- as.vector(matrix(rep(dose[[18]][,2],2),nrow=2,byrow=T))
dy <- c(0,as.vector(matrix(rep(dose[[18]][,1],2),nrow=2,byrow=T)))
dy <- dy[1:(length(dy)-1)]
plot(dx,dy,type="l",xlim=c(-200,1400),ylim=c(0,3),xlab="",ylab="Dose",
	main="AZ + P",yaxt="n")
axis(2,at=c(0,1,2,3))
for(i in 19:32){
	dx <- as.vector(matrix(rep(dose[[i]][,2],2),nrow=2,byrow=T))
	dy <- c(0,as.vector(matrix(rep(dose[[i]][,1],2),nrow=2,byrow=T)))
	dy <- dy[1:(length(dy)-1)]
	lines(dx,dy)}
dx <- as.vector(matrix(rep(dose[[33]][,2],2),nrow=2,byrow=T))
dy <- c(0,as.vector(matrix(rep(dose[[33]][,1],2),nrow=2,byrow=T)))
dy <- dy[1:(length(dy)-1)]
plot(dx,dy,type="l",xlim=c(-200,1400),ylim=c(0,3),yaxt="n",
	xlab="Days from start of treatment",ylab="Dose",main="AZ + MP")
axis(2,at=c(0,1,2,3))
for(i in 34:48){
	dx <- as.vector(matrix(rep(dose[[i]][,2],2),nrow=2,byrow=T))
	dy <- c(0,as.vector(matrix(rep(dose[[i]][,1],2),nrow=2,byrow=T)))
	dy <- dy[1:(length(dy)-1)]
	lines(dx,dy)}
dev.off()
}

# this is how the Jacobian for the sqrt transform in carma, elliptic,
#and kalseries worked before version 0.8 - wrong but differences in AIC
#are correct
resp$y <- sqrt(resp$y)
resp$delta <- matrix(ifelse(resp$y==0,1,1/resp$y))

# without dose

# polynomial curve
print(u0 <- carma(resp))
print(u1 <- carma(resp,torder=1))
print(u1t <- carma(resp,torder=1,ccov=treat))
print(u1i <- carma(resp,torder=1,ccov=treat,interact=c(1,1)))
print(u2 <- carma(resp,torder=2))
print(u2t <- carma(resp,torder=2,ccov=treat))
print(u2i <- carma(resp,torder=2,ccov=treat,interact=c(2,2)))
print(u0re <- carma(resp,pre=0.8,pos=c(1,1)))
print(u1re <- carma(resp,torder=1,pre=0.8,pos=c(1,1)))
print(u1ret <- carma(resp,torder=1,ccov=treat,pre=0.8,pos=c(1,1)))
print(u1rei <- carma(resp,torder=1,ccov=treat,interact=c(1,1),pre=0.8,
	pos=c(1,1)))
print(u2re <- carma(resp,torder=2,pre=0.8,pos=c(1,1)))
print(u2ret <- carma(resp,torder=2,ccov=treat,pre=0.8,pos=c(1,1)))
print(u2rei <- carma(resp,torder=2,ccov=treat,interact=c(2,2),pre=0.8,
	pos=c(1,1)))
print(u0ar <- carma(resp,arma=c(1,0,0),par=-3))
print(u1ar <- carma(resp,torder=1,arma=c(1,0,0),par=1))
print(u1art <- carma(resp,torder=1,ccov=treat,arma=c(1,0,0),par=-3))
print(u1ari <- carma(resp,torder=1,ccov=treat,interact=c(1,1),arma=c(1,0,0),
	par=-3))
print(u2ar <- carma(resp,torder=2,arma=c(1,0,0),par=1))
print(u2art <- carma(resp,torder=2,ccov=treat,arma=c(1,0,0),par=1))
print(u2ari <- carma(resp,torder=2,ccov=treat,interact=c(2,2),arma=c(1,0,0),
	par=-2))
print(u0ra <- carma(resp,pre=0.8,pos=c(1,1),arma=c(1,0,0),par=-3))
print(u1ra <- carma(resp,torder=1,pre=0.8,pos=c(1,1),arma=c(1,0,0),
	par=-2))
print(u1rat <- carma(resp,torder=1,ccov=treat,pre=0.8,pos=c(1,1),
	arma=c(1,0,0),par=-2.5))
print(u1rai <- carma(resp,torder=1,ccov=treat,interact=c(1,1),arma=c(1,0,0),
	par=-3,pre=0.8,pos=c(1,1)))
print(u2ra <- carma(resp,torder=2,pre=0.8,pos=c(1,1),arma=c(1,0,0),
	par=-2))
print(u2rat <- carma(resp,torder=2,ccov=treat,pre=0.8,pos=c(1,1),
	arma=c(1,0,0),par=-2))
print(u2rai <- carma(resp,torder=2,ccov=treat,interact=c(2,2),pre=0.8,
	pos=c(1,1),arma=c(1,0,0),par=-2))

if(interactive()){
postscript(file="azamprof.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(mprofile(u2rai,ccov=c(0,0),plotse=F),ylim=c(0,1200),
	xlab="Days from start of treatment",ylab="AFCR level",yaxt="n")
axis(2,at=c(0,400,800,1200))
plot(mprofile(u2rai,ccov=c(1,0),plotse=F),add=T,lty=3)
plot(mprofile(u2rai,ccov=c(0,1),plotse=F),add=T,lty=2)
legend(800,1000,legend=c("P + P","AZ + P","AZ + MP"),lty=1:3,bty="n")
dev.off()
}

# logistic curve
print(z0 <- elliptic(resp,preg=c(5.734,4.628,1.716,-1.497),pvar=26.4,
	link="square",model="logistic"))
print(z1 <- elliptic(resp,preg=c(5.72,5.06,1.52,-1.56,-0.048,-1.12,
	0.005,-0.02,0.11,-0.76,0.081,0.018),
	pvar=20,ccov=treat,link="square",model="logistic"))
print(z0re <- elliptic(resp,preg=c(5.734,4.628,1.716,-1.497),pvar=26.4,pre=7.4,
	link="square",model="logistic"))
print(z1re <- elliptic(resp,preg=c(5.72,5.2,2.6,-2,-0.05,-1.2,
	-0.02,-2.3,0.08,-0.86,2.2,-2),pvar=13.36,pre=6.54,
	ccov=treat,link="square",model="logistic",iter=200))
print(z0ar <- elliptic(resp,preg=c(5.765,4.66,13,-3.9),pvar=30.7,
	par=0.98,link="square",model="logistic"))
print(z1ar <- elliptic(resp,preg=c(5.8,5.1,2,-2,-0.06,-1.2,
	0.003,-0.2,0.08,-0.85,-0.12,-1.6),pvar=20,par=0.92,
	ccov=treat,link="square",model="logistic",iter=200))
print(z0ra <- elliptic(resp,preg=c(5.734,4.63,19,-5),pvar=14.7,pre=12,
	par=0.87,link="square",model="logistic"))
print(z1ra <- elliptic(resp,preg=c(5.72,5.2,2.6,-2,-0.05,-1.2,
	-0.02,-2.3,0.08,-0.86,2.2,-2),model="logistic",iter=200,
	pvar=4.3,pre=6.5,par=0.9,ccov=treat,link="square"))

if(interactive()){
postscript(file="azamspr2.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
rsp <- function(p,y){
	y0 <- exp(p[1]+p[5]*(trt==2)+p[9]*(trt==3))
	yinf <- exp(p[2]+p[6]*(trt==2)+p[10]*(trt==3))
	p[3] <- p[3]+p[7]*(trt==2)+p[11]*(trt==3)
	p[4] <- p[4]+p[8]*(trt==2)+p[12]*(trt==3)
	yinf*(1+((yinf/y0)^p[4]-1)*exp(-yinf^p[4]*exp(p[3])*y))^(-1/p[4])}
trt <- 1
plot(mprofile(z1ra,mu=rsp),ylim=c(0,1200),
	xlab="Days from start of treatment",ylab="AFCR level",yaxt="n")
axis(2,at=c(0,400,800,1200))
trt <- 2
plot(mprofile(z1ra,mu=rsp),nind=18,add=T,lty=3)
trt <- 3
plot(mprofile(z1ra,mu=rsp),nind=33,add=T,lty=2)
legend(800,1000,legend=c("P + P","AZ + P","AZ + MP"),lty=1:3,bty="n")
dev.off()
}

# with dose

tvc <- gettvc(y,tvcov=dose,ties=F)
tvc2 <- list()
for(i in y) tvc2 <- c(tvc2,list(cbind((i[,2]-501.4581)/100,
	(i[,2]-501.4581)^2/10000)))
tvc <- tvctomat(tvc2,names= c("t","t2"),old=tvc)
tvc <- tvctomat(tvc,interaction=c("t","t2","dose"),ccov=treat)
rm(tvc2)
reps <- rmna(resp,tvcov=tvc,ccov=tcctomat(treat))

# Heitjan's linear model
mu0 <- function(p) p[1]+p[2]*dose+p[3]*(dose>0)
mut <- function(p) p[1]+p[2]*dose+p[3]*(dose>0)+(p[4]*dose+
	p[5]*(dose>0))*AZP+(p[6]*dose+p[7]*(dose>0))*AZMP
print(s0 <- elliptic(reps,preg=c(10.6,0,0),pvar=14.7,model=mu0))
print(s0t <- elliptic(reps,preg=c(10.6,0,0,0,0,0,0),pvar=14.7,model=mut))
print(s0re <- elliptic(reps,preg=c(10.6,0,0),pvar=14.7,pre=11,model=mu0))
print(s0ret <- elliptic(reps,preg=c(15,-2.2,4.3,0.6,-8.4,-0.4,-4.5),pvar=14.7,
	pre=11,model=mut))
print(s0ar <- elliptic(reps,preg=c(13,0.1,-3),pvar=36,par=0.98,model=mu0))
print(s0art <- elliptic(reps,preg=c(15,-2.2,4.3,0.6,-8.4,-0.4,-4.5),pvar=18,
	par=0.9,model=mut))
print(s0ra <- elliptic(reps,preg=c(10.6,0,0),pvar=4,pre=5,par=0.9,model=mu0))
print(s0rat <- elliptic(reps,preg=c(14,-1.6,4.3,0.4,-7.8,-0.3,-5.3),pvar=18,
	pre=8,par=0.9,model=mut))

# polynomial curve
mu <- function(p) {
	p[1]+p[2]*t+p[3]*t^2+(p[4]+p[5]*t+p[6]*t^2)*AZP+
	(p[7]+p[8]*t+p[9]*t^2)*AZMP+dose*(p[10]+p[11]*AZP+p[12]*AZMP)}
print(v1 <- elliptic(reps,pvar=20,tvcov=~dose,torder=2))
print(v1t <- elliptic(reps,pvar=15,ccov=~AZP+AZMP,tvcov=~dose,torder=2))
print(v1i <- elliptic(reps,pvar=12.7,ccov=~AZP+AZMP,inter=c(2,2),
	tvcov=~dose,torder=2))
print(r1di <- elliptic(reps,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,model=mu,torder=1))
print(v1re <- elliptic(reps,pvar=20,tvcov=~dose,torder=2,pre=15))
print(v1ret <- elliptic(reps,pvar=13.4,ccov=~AZP+AZMP,tvcov=~dose,
	torder=2,pre=6.3))
print(v1rei <- elliptic(reps,pvar=12.7,ccov=~AZP+AZMP,inter=c(2,2),
	tvcov=~dose,torder=2,pre=6.3))
print(r1redi <- elliptic(reps,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,pre=6.4,model=mu,
	torder=1))
print(v1ar <- elliptic(reps,pvar=20,tvcov=~dose,torder=2,
	par=0.5))
print(v1art <- elliptic(reps,pvar=13.4,ccov=~AZP+AZMP,tvcov=~dose,
	torder=2,par=0.9))
print(v1ari <- elliptic(reps,pvar=12.7,ccov=~AZP+AZMP,inter=c(2,2),
	tvcov=~dose,torder=2,par=0.9))
print(r1ardi <- elliptic(reps,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,par=0.81,
	model=mu,torder=1,iter=200))
print(v1ra <- elliptic(reps,pvar=20,tvcov=~dose,
	torder=2,pre=11,par=0.8))
print(v1rat <- elliptic(reps,pvar=13.4,ccov=~AZP+AZMP,tvcov=~dose,
	torder=2,pre=6.3,par=0.9))
print(v1rai <- elliptic(reps,pvar=12.7,ccov=~AZP+AZMP,inter=c(2,2),
	tvcov=~dose,torder=2,pre=6.3,par=0.9))
print(r1radi <- elliptic(reps,preg=c(13.5,-0.45,0.057,-4.1,-0.41,0.057,-3.4,
	-0.44,0.0067,0.51,-2,-1.4),pvar=13.1,pre=6.4,par=0.81,
	model=mu))

# logistic curve
print(z2 <- elliptic(reps,tvcov=~dose,preg=c(5.59,-10.46,1.41,8.6),pvar=27.5,
 	link="square",model="logistic"))
print(z3 <- elliptic(reps,tvcov=~dose,preg=c(5.608,6.15,-2.41,.4030,1.579,
	1.153),pvar=21.7,ccov=~AZP+AZMP,link="square",
	model="logistic"))
print(z2re <- elliptic(reps,tvcov=~dose,preg=c(5.58,-14,1.6,7.55),
	pvar=15.5,pre=11.7,link="square",model="logistic"))
print(z3re <- elliptic(reps,tvcov=~dose,preg=c(5.617,-.2980,-1.129,
	.4540,1.667,1.403),pvar=13.4,pre=8,ccov=~AZP+AZMP,
	link="square",model="logistic"))
print(z2ar <- elliptic(reps,tvcov=~dose,preg=c(5.54,-13.6,1.5,7.7),
	pvar=31.9,par=0.99,link="square",model="logistic"))
print(z3ar <- elliptic(reps,tvcov=~dose,preg=c(5.583,5.866,-2.367,
	.3820,1,1.141),pvar=24,par=0.5,ccov=~AZP+AZMP,
	link="square",model="logistic"))
print(z2ra <- elliptic(reps,tvcov=~dose,preg=c(5.54,1.3,-1.3,0.85),
	pvar=15.9,pre=14.7,par=0.02,link="square",
	model="logistic"))
print(z3ra <- elliptic(reps,tvcov=~dose,preg=c(5.6,1.9,-1.5,
	.43,1.5,1.36),pvar=13.4,par=0.9,pre=8.2,ccov=~AZP+AZMP,
	link="square",model="logistic"))

# Chapter 6
print(r1reel <- elliptic(reps,preg=c(13.08,-0.44,0.057,-3.48,-0.38,0.051,-3.49,
	-0.48,0.074,0.54,-2.24,-1.39),pvar=0.8,pre=0.35,
	model=mu,torder=1,dist="power exp",pell=0.6))
print(r1arel <- elliptic(reps,preg=c(13.08,-0.44,0.057,-3.48,-0.38,0.051,-3.49,
	-0.48,0.074,0.54,-2.24,-1.39),pvar=0.8,par=0.79,
	model=mu,torder=1,dist="power exp",pell=0.6))

print(k2retd <- kalseries(resp,intensity="normal",dep="frailty",pinit=0.35,
	psh=10.68,preg=c(11.93,-2.42,-2.6),ccov=treat,tvc=tvc,
	ptvc=c(0.72,-0.47,0.066,-0.32,-0.4,0.041,0.062,-2.45,-1.94),iter=200))
#equivalently
#print(k2retd <- kalseries(reps,intensity="normal",dep="frailty",pinit=0.35,
#	psh=10.68,preg=c(11.93,-2.42,-2.6),ccov=~AZP+AZMP,
#	tvc=~dose+times+I(times^2)+(times+I(times^2)):(AZP+AZMP)+
#	dose:(AZP+AZMP),ptvc=c(0.72,-0.0047,0.0000066,-2.45,-1.94,-0.0032,
#	-0.004,0.0000041,0.0000062),iter=200))
print(kl2retd <- kalseries(resp,intensity="logistic",dep="frailty",pinit=0.28,
	psh=3.57,preg=c(12.25,-2.86,-2.82),ccov=treat,tvc=tvc,
	ptvc=c(0.72,-0.48,0.067,-0.32,-0.42,0.04,0.064,-2.44,-1.91)))
print(kc2retd <- kalseries(resp,intensity="Cauchy",dep="frailty",pinit=0.16,
	psh=4.93,preg=c(12.78,-3.61,-2.84),ccov=treat,tvc=tvc,
	ptvc=c(0.72,-0.55,0.073,-0.32,-0.41,0.036,0.064,-2.44,-2.08)))
print(k2artd <- kalseries(resp,intensity="normal",dep="serial",pinit=0.478,
	pdep=0.999,psh=8.81,preg=c(11.4,-2.37,-2.89),ccov=treat,
	tvc=tvc,
	ptvc=c(0.74,-0.416,0.065,-0.388,-0.454,0.034,0.07,-2.35,-1.66)))
print(kl2artd <- kalseries(resp,intensity="logistic",dep="serial",pinit=0.35,
	pdep=0.998,psh=3.27,preg=c(12.08,-2.8,-2.84),ccov=treat,
	tvc=tvc,
	ptvc=c(0.76,-0.47,0.066,-0.35,-0.44,0.037,0.067,-2.45,-1.89)))
print(kc2artd <- kalseries(resp,intensity="Cauchy",dep="serial",pinit=0.16,
	pdep=0.99,psh=4.92,preg=c(13.2,-3.75,-3.27),ccov=treat,
	tvc=tvc,
	ptvc=c(0.072,-0.53,0.066,-0.33,-0.45,0.039,0.53,-2.45,-1.89)))
print(k2mtd <- kalseries(resp,intensity="normal",dep="Markov",pinit=0.272,
	pdep=0.998,psh=8.81,preg=c(13.962,-2.573,-2.239),ccov=treat,
	tvc=tvc,iter=200,
	ptvc=c(1.139,-0.29,0.0559,-0.305,-0.391,0.0232,0.0608,-2.448,-1.88)))
print(kl2mtd <- kalseries(resp,intensity="logistic",dep="Markov",pinit=0.153,
	pdep=0.998,psh=5.43,preg=c(13.206,-2.774,-2.467),ccov=treat,
	tvc=tvc,
	ptvc=c(1.068,-0.379,0.0603,-0.315,-0.408,0.0284,0.068,-2.45,-1.866)))
print(kc2mtd <- kalseries(resp,intensity="Cauchy",dep="Markov",pinit=0.004,
	pdep=0.997,psh=5.626,preg=c(12.513,-3.448,-2.977),ccov=treat,
	tvc=tvc,iter=200,
	ptvc=c(0.679,-0.53,0.0696,-0.35,-0.455,0.0343,0.0725,-2.446,-1.888)))
print(k2arretd <- kalseries(resp,intensity="normal",dep="frailty",pinit=0.34,
	psh=10.73,preg=c(11.83,-2.43,-2.56),ccov=treat,tvc=tvc,pdep=0.76,
	ptvc=c(0.77,-0.47,0.067,-0.33,-0.41,0.043,0.062,-2.39,-1.9),iter=200))

if(interactive()){
# because of sqrt transform above:
k2artd$response$y <- k2artd$response$y^2
k2artd$pred <- k2artd$pred^2
k2artd$rpred <- k2artd$rpred^2
postscript(file="azamipr.eps",width=5,height=7)
par(mfrow=c(3,1),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(x=0,y=0,type="n",main="Placebos",xlim=c(-200,1400),ylim=c(0,1200),
	xlab="",ylab="AFCR",yaxt="n")
axis(2,at=c(0,400,800,1200))
plot(iprofile(k2artd),add=T)
plot(iprofile(k2artd),nind=17,add=T,lty=3,pch=2)
plot(x=0,y=0,type="n",main="Azathioprine + placebo",
	xlab="",ylab="AFCR",xlim=c(-200,1400),ylim=c(0,1200),yaxt="n")
axis(2,at=c(0,400,800,1200))
plot(iprofile(k2artd),nind=18,add=T)
plot(iprofile(k2artd),nind=32,add=T,lty=3,pch=2)
plot(x=0,y=0,type="n",main="Azathioprine + methylprednisolone",
	xlab="Days",ylab="AFCR",xlim=c(-200,1400),ylim=c(0,1200),yaxt="n")
axis(2,at=c(0,400,800,1200))
plot(iprofile(k2artd),nind=33,add=T)
plot(iprofile(k2artd),nind=48,add=T,lty=3,pch=2)
dev.off()
}
