library(growth)

level <- read.table("bloodsug.dat",skip=6,head=T)
times <- c(0,1.5,3,4.5,6)
treat <- c(rep(c(0,1),22),rep(c(1,0),22))
period <- c(rep(c(1,2,3,4),22))
group <- gl(2,44,88)

# outliers at third time
out <- NULL
for(i in 1:88)out <- c(out,level[i,2]<level[i,3]&&level[i,4]<level[i,3])
level[out,]

if(interactive()){
postscript("bloodsug.eps",height=5)
par(mfrow=c(1,2),font.main=1)
plot(times,level[1,],type="l",ylim=c(0,120),xlab="Hours after injection",
	ylab="Blood sugar level",main="Treatment A",lty=4)
for(i in seq(5,41,by=4))lines(times,level[i,],lty=4)
for(i in seq(3,43,by=4))lines(times,level[i,],lty=3)
for(i in seq(46,86,by=4))lines(times,level[i,],lty=2)
for(i in seq(48,88,by=4))lines(times,level[i,])
legend(1,120,legend=c("Period 1","Period 2","Period 3","Period 4"),
	lty=1:4,bty="n")
plot(times,level[2,],type="l",ylim=c(0,120),xlab="Hours after injection",
	ylab="",main="Treatment B",lty=2)
for(i in seq(6,42,by=4))lines(times,level[i,],lty=2)
for(i in seq(4,44,by=4))lines(times,level[i,])
for(i in seq(45,85,by=4))lines(times,level[i,],lty=4)
for(i in seq(47,87,by=4))lines(times,level[i,],lty=3)
legend(1,120,legend=c("Period 1","Period 2","Period 3","Period 4"),
	lty=1:4,bty="n")
}

lev <- restovec(level,times=times)
carma(lev)
carma(lev,ccov=treat)
carma(lev,ccov=~group)
carma(lev,ccov=~group+treat)
carma(lev,torder=2)
carma(lev,ccov=treat,torder=2)
carma(lev,ccov=~treat+group+as.factor(period),torder=2)
carma(lev,ccov=~treat+group+period,torder=2)
carma(lev,ccov=~treat+group+as.factor(period),torder=2,int=rep(2,5))
carma(lev,ccov=~treat+group+I(period==4),torder=2,inter=c(2,2,2))
carma(lev,ccov=~treat+group+I(period==4),torder=2,inter=c(1,2,1))
carma(lev,ccov=~treat+group+I(period==4),torder=2,
	inter=c(1,2,1),pre=80,pos=c(1,1))
carma(lev,ccov=~treat+group+I(period==4),torder=2,
	inter=c(1,2,1),arma=c(1,0,0),par=0.5)
carma(lev,ccov=~treat+group+I(period==4),torder=2,
	inter=c(1,2,1),arma=c(1,0,0),par=0.5,pre=90,pos=c(1,1))

y <- restovec(matrix(t(as.matrix(level)),ncol=20,byrow=T),times=rep(times,4),
	nest=rep(1:4,rep(5,4)))
trt <- matrix(c(rep(rep(c(rep(0,5),rep(1,5)),2),11),
	rep(rep(c(rep(1,5),rep(0,5)),2),11)),ncol=20,byrow=T)
grp <- gl(2,11,22)
per1 <- matrix(0,ncol=3,nrow=20)
per1[1:5,1] <- 1
per1[6:10,2] <- 1
per1[11:15,3] <- 1
per <- list()
for(i in 1:22) per <- c(per,list(per1))
per1 <-  matrix(rep(c(rep(0,5),rep(1,15)),22),ncol=20,byrow=T)
per4 <-  matrix(rep(c(rep(0,15),rep(1,5)),22),ncol=20,byrow=T)
per4trt <- list()
for(i in 1:11)per4trt <- c(per4trt,list(cbind(rep(c(rep(0,5),rep(1,5)),2),
	c(rep(0,15),rep(1,5)))))
for(i in 1:11)per4trt <- c(per4trt,list(cbind(rep(c(rep(1,5),rep(0,5)),2),
	c(rep(0,15),rep(1,5)))))
for(i in 1:22)colnames(per4trt[[i]]) <- c("trt","per4")
per4int <- list()
for(i in 1:22){
	per4int <- c(per4int,list(cbind(c(rep(0,15),rep(1,5)),
		c(rep(0,15),seq(-3,3,by=1.5)))))
	colnames(per4int[[i]]) <- c("per4","per4.t^1")}
per4int2 <- list()
for(i in 1:22){
	per4int2 <- c(per4int2,list(cbind(c(rep(0,15),rep(1,5)),
		c(rep(0,15),seq(-3,3,by=1.5)),c(rep(0,15),
		seq(-3,3,by=1.5)^2))))
	colnames(per4int2[[i]]) <- c("per4","per4.t^1","per4.t^2")}
per4trtint <- list()
for(i in 1:11)per4trtint <- c(per4trtint,list(cbind(
	rep(c(rep(0,5),rep(1,5)),2),rep(c(rep(0,5),rep(1,5)),2)*
	rep(seq(-3,3,by=1.5),4),
	c(rep(0,15),rep(1,5)),c(rep(0,15),seq(-3,3,by=1.5)))))
for(i in 1:11)per4trtint <- c(per4trtint,list(cbind(
	rep(c(rep(1,5),rep(0,5)),2),rep(c(rep(1,5),rep(0,5)),2)*
	rep(seq(-3,3,by=1.5),4),
	c(rep(0,15),rep(1,5)),c(rep(0,15),seq(-3,3,by=1.5)))))
for(i in 1:22)colnames(per4trtint[[i]]) <- c("trt","trt.t^1","per4","per4.t^1")

elliptic(y,tvcov=trt,torder=2,pvar=360)
elliptic(y,ccov=~grp,torder=2,pvar=360)
elliptic(y,tvcov=per,torder=2,pvar=360)
elliptic(y,tvcov=per4,torder=2,pvar=360)
elliptic(y,ccov=~grp,int=2,tvcov=per1,torder=2,pvar=360)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=360)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=250,pre=90)
elliptic(y,ccov=~grp,int=2,tvcov=per,torder=2,pvar=220,pre=c(55,35))
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=220,pre=c(40,80))
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=300,par=0.56)

# best model: multivariate normal
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=258,par=0.44,
	pre=c(45,0.01))
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=258,par=0.443,pre=45.37)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=258,par=0.443)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=258,pre=45.37)

# remove outliers
yy <- matrix(t(as.matrix(level)),ncol=20,byrow=T)
yy[2,13] <- yy[3,3] <- NA
yy <- restovec(yy,times=rep(times,4),nest=rep(1:4,rep(5,4)))
elliptic(yy,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=258,par=0.443,pre=45.37)
elliptic(yy,ccov=~grp,int=2,tvcov=per4trt,torder=2,
	pvar=258,par=0.443,pre=45.37)

# best model: multivariate elliptically contoured
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,
	pvar=1.7,par=0.433,pre=c(0.25,0.1),pell=0.5)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,
	pvar=1.7,par=0.433,pre=0.25,pell=0.5)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=1.7,par=0.433,pell=0.5)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=1.7,pre=0.34,pell=0.47)

# remove outliers
elliptic(yy,ccov=~grp,int=2,tvcov=per4,torder=2,
	pvar=1.7,par=0.443,pre=0.5,pell=1)
elliptic(yy,ccov=~grp,int=2,tvcov=per4trt,torder=2,
	pvar=1.7,par=0.443,pre=0.34,pell=0.5)

elliptic(y,ccov=~grp,int=2,tvcov=per4trt,torder=2,pvar=258,par=0.443,pre=45.37)
elliptic(y,ccov=~grp,int=2,tvcov=per4trt,torder=2,
	pvar=1.7,par=0.443,pre=0.34,pell=0.5)

elliptic(y,ccov=~grp,int=2,tvcov=per4int,torder=2,pvar=258,par=0.443,pre=45.37)
elliptic(y,ccov=~grp,int=2,tvcov=per4int,torder=2,pvar=258,par=0.443)
elliptic(y,ccov=~grp,int=2,tvcov=per4int,torder=2,pvar=258,pre=45.37)
elliptic(y,ccov=~grp,int=2,torder=2,pvar=258,pre=45.37)
elliptic(y,tvcov=per4int,torder=2,pvar=258,pre=45.37)
elliptic(y,ccov=~grp,int=2,tvcov=per4int2,torder=2,
	pvar=255.5,par=0.436,pre=45.37)
elliptic(y,ccov=~grp,int=2,tvcov=per4trtint,torder=2,
	pvar=255.5,par=0.436,pre=45.37)
elliptic(y,ccov=~grp,int=2,tvcov=per4trtint,torder=2,
	pvar=1.8,par=0.435,pre=0.26,pell=0.5)

# variance depending on time
timesv <- rep(times,88)
varfn <- function(p) p[1]+p[2]*timesv
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=c(5.6,0),par=0.443,
	pre=45.37,varfn=varfn,preg=c(40.1,-2.4,4.6,-6.6,1.5,1.1,15.4))
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=c(5.6,0),pre=45.37,
	varfn=varfn,preg=c(40.1,-2.4,4.6,-6.6,1.5,1.1,15.4))
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=c(5.6,0),par=0.443,
	varfn=varfn,preg=c(40.1,-2.4,4.6,-6.6,1.5,1.1,15.4))
elliptic(y,ccov=~grp,int=2,tvcov=per4trtint,torder=2,pvar=c(5.5,0),par=0.436,
	pre=45.37,varfn=varfn,
	preg=c(39.5,-2.7,4.6,-6.6,1.8,1.1,1.2,1.5,15.4,1.3))
elliptic(y,ccov=~grp,int=2,torder=2,pvar=c(5.5,0),pre=45.37,varfn=varfn,
	preg=c(44,-1.2,4.6,-6.6,1.9,1.1))
elliptic(y,tvcov=per4int,torder=2,pvar=c(5.5,0),pre=45.37,varfn=varfn,
	preg=c(36.7,-0.7,5.1,15.7,1.6))

elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,
	pvar=c(-1.8,0.24),par=0.37,pre=0.04,varfn=varfn,
	preg=c(40.2,-1,4.9,-10.3,1.7,1.6,13.8),pell=0.41)
elliptic(y,ccov=~grp,int=2,tvcov=per4trtint,torder=2,
	pvar=c(-2.7,0.24),par=0.34,pre=0.02,varfn=varfn,
	preg=c(39.3,-2,4.9,-10.4,1.7,1.6,1.4,1.2,15.7,1.6),pell=0.38)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=c(-1.8,0.24),par=0.37,
	varfn=varfn,preg=c(40.2,-1,4.9,-10.3,1.7,1.6,13.8),pell=0.41)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,pvar=c(-1.8,0.24),pre=0.04,
	varfn=varfn,preg=c(40.2,-1,4.9,-10.3,1.7,1.6,13.8),pell=0.41)
elliptic(y,ccov=~grp,int=2,tvcov=per4,torder=2,
	pvar=c(-1.8,0.24),par=0.37,pre=c(0.04,0.01),varfn=varfn,
	preg=c(40.2,-1,4.9,-10.3,1.7,1.6,13.8),pell=0.41)

elliptic(y,ccov=~grp,int=2,tvcov=per4trtint,torder=2,
	pvar=251.6,par=0.426,pre=c(45.37,1))
elliptic(y,ccov=~grp,int=2,tvcov=per4trtint,torder=2,pvar=255.5,pre=45.37)
elliptic(y,tvcov=per4trtint,torder=2,pvar=255.5,pre=45.37)

if(interactive()){
pl <- function(t,grp,per,trt)39.289-1.992*(t-3)+4.855*(t-3)^2-10.428*grp+
	1.678*grp*(t-3)+1.594*grp*(t-3)^2+15.697*per+1.574*per*(t-3)+
	1.422*trt+1.234*(t-3)
postscript("bldsugpr.eps",height=5)
par(mfrow=c(1,2),font.main=1)
plot(times,pl(times,0,0,0),type="l",ylim=c(0,120),xlab="Hours after injection",
	ylab="Blood sugar level",main="Treatment A",lty=4)
lines(times,pl(times,0,1,0),lty=1)
lines(times,pl(times,1,0,0),lty=2)
lines(times,pl(times,1,1,0),lty=3)
legend(1,120,legend=c("Periods 1-3, Group 1","Period 4,       Group 1",
	"Periods 1-3, Group 2","Period 4,       Group 2"),lty=c(4,1:3),bty="n")
plot(times,pl(times,0,0,1),type="l",ylim=c(0,120),xlab="Hours after injection",
	ylab="",main="Treatment B",lty=4)
lines(times,pl(times,0,1,1),lty=1)
lines(times,pl(times,1,0,1),lty=2)
lines(times,pl(times,1,1,1),lty=3)
legend(1,120,legend=c("Periods 1-3, Group 1","Period 4,       Group 1",
	"Periods 1-3, Group 2","Period 4,       Group 2"),lty=c(4,1:3),bty="n")
}
