library(gnlm)

comp <- as.matrix(read.table("comp.dat",header=T, skip=2))
year <- 1978:1987
output <- as.matrix(read.table("output.dat",header=T, skip=2))

if(interactive()){
postscript("comp.eps",height=9)
par(mfrow=c(2,1),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(restovec(comp,times=year),nind=1:6,ylim=c(0,20),xlab="",
	ylab="Hourly wage",lty=1)
points(year,comp[1,])
for(i in 2:6)points(year,comp[i,],pch=i)
legend(1978,20,legend=rownames(comp)[1:3],pch=1:3,bty="n")
legend(1982,20,legend=rownames(comp)[4:6],pch=4:6,bty="n")
plot(restovec(comp,times=year),nind=7:10,ylim=c(0,20),xlab="Year",
	ylab="Hourly wage",lty=1)
points(year,comp[7,],pch=1)
for(i in 8:10)points(year,comp[i,],pch=i-6)
legend(1978,20,legend=rownames(comp)[7:10],pch=c(7:10)-6,bty="n")
dev.off()
postscript("output.eps",height=9)
par(mfrow=c(2,1),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(restovec(output,times=year),nind=1:6,ylim=c(0,20),xlab="",
	ylab="Hourly output",lty=1)
points(year,output[1,])
for(i in 2:6)points(year,output[i,],pch=i)
legend(1978,7,legend=rownames(comp)[1:3],pch=1:3,bty="n")
legend(1982,7,legend=rownames(comp)[4:6],pch=4:6,bty="n")
plot(restovec(output,times=year),nind=7:10,ylim=c(0,20),xlab="Year",
	ylab="Hourly output",lty=1)
points(year,output[7,],pch=1)
for(i in 8:10)points(year,output[i,],pch=i-6)
legend(1983,12,legend=rownames(output)[7:10],pch=c(7:10)-6,bty="n")
dev.off()
}

comp1 <- as.matrix(comp)
compm <- mean(comp1)
print(s1 <- t(comp1-compm)%*%(comp1-compm)/10)
v1 <- sqrt(diag(s1))
for(i in 2:10)for(j in 1:(i-1))s1[i,j] <- s1[i,j]/v1[i]/v1[j]

# serial correlation
y <- as.vector(t(comp1[,2:10]))
summary(z0 <- glm(y~1))
z0$aic/2
y1 <- as.vector(t(comp1[,1:9]))
summary(z1 <- glm(y~y1))
z1$aic/2

region <- c(rep(0,54),rep(1,36))
summary(z2 <- glm(y~y1*region))
z2$aic/2

x <- as.vector(t(as.matrix(output)[,2:10]))
x1 <- as.vector(t(as.matrix(output)[,1:9]))
summary(z3 <- glm(y~x))
z3$aic/2
summary(z4 <- glm(y~x*region))
z4$aic/2
region2 <- c(rep(0,54),rep(1,9),rep(0,18),rep(1,9))
region3 <- c(rep(0,63),rep(1,18),rep(0,9))
summary(z5 <- glm(y~x*(region2+region3)))
z5$aic/2

mu <- function(p) p[1]*(y1+p[2]+p[3]*x1)-p[2]-p[3]*x
gnlr(y,dist="normal",pmu=rep(1,3),psh=1,mu=mu)
mu <- function(p) p[1]*(y1+p[2]+p[4]*region+p[3]*x1+p[5]*x1*region)-
	p[2]-p[4]*region-p[3]*x-p[5]*x*region
gnlr(y,dist="normal",pmu=rep(1,5),psh=1,mu=mu)
mu <- function(p) p[1]*(y1+p[6]*y1*region+p[2]+p[4]*region+p[3]*x1+
	p[5]*x1*region)-p[2]-p[4]*region-p[3]*x-p[5]*x*region
gnlr(y,dist="normal",pmu=rep(1,6),psh=1,mu=mu,iter=200)

if(interactive()){
postscript("compdiff.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot((x-x1)[1:54],(y-y1)[1:54],xlab="Hourly output difference",
	ylab="Hourly wage difference",xlim=c(-2,2),ylim=c(-4,4))
points((x-x1)[55:90],(y-y1)[55:90],pch=3)
legend(-2,-2,legend=c("Europe","Others"),pch=c(1,3),bty="n")
dev.off()
}

# random walk
summary(z6 <- glm(y-y1~+I(x-x1)))
z6$aic/2
summary(z7 <- glm(y-y1~+I(x-x1)*region))
z7$aic/2

# state dependence
summary(z8 <- glm(y~y1+x))
z8$aic/2
summary(z9 <- glm(y~y1+x*region))
z9$aic/2
summary(z10 <- glm(y~(y1+x)*region))
z10$aic/2

# general AR
summary(z11 <- glm(y~x1))
z11$aic/2
summary(z12 <- glm(y~x1*region))
z12$aic/2
summary(z13 <- glm(y~y1+x+x1))
z13$aic/2
summary(z14 <- glm(y~y1+(x+x1)*region))
z14$aic/2
summary(z15 <- glm(y~y1*region+(x+x1)*region))
z15$aic/2

# conditional ante-dependence

# constant variance
date <- gl(9,1,90)
summary(z16 <- glm(y~y1*date))
z16$aic/2
summary(z17 <- glm(y~y1*date+region*date))
z17$aic/2
summary(z18 <- glm(y~y1*date*region))
z18$aic/2
summary(z19a <- glm(y~y1*date*region,weight=region==0))
summary(z19b <- glm(y~y1*date*region,weight=region==1))
(z19a$aic+z19b$aic)/2

# changing variance
taic <- 0
for(i in 1:9){
	zz <- glm(comp1[,i+1]~comp1[,i])
	taic <- taic+zz$aic/2}
taic
taic <- 0
for(i in 1:9){
	zz <- glm(comp1[,i+1]~comp1[,i]+c(rep(0,6),rep(1,4)))
	taic <- taic+zz$aic/2}
taic
taic <- 0
for(i in 1:9){
	zz <- glm(comp1[,i+1]~comp1[,i]*c(rep(0,6),rep(1,4)))
	taic <- taic+zz$aic/2}
taic
taic <- 0
mu <- rho <- xi <- matrix(0,ncol=9,nrow=2)
for(i in 1:9){
	zz <- glm(comp1[1:6,i+1]~comp1[1:6,i])
	mu[1,i] <- zz$coef[1]
	rho[1,i] <- zz$coef[2]
	xi[1,i] <- zz$dev/6
	taic <- taic+zz$aic/2}
for(i in 1:9){
	zz <- glm(comp1[7:10,i+1]~comp1[7:10,i])
	mu[2,i] <- zz$coef[1]
	rho[2,i] <- zz$coef[2]
	xi[2,i] <- zz$dev/4
	taic <- taic+zz$aic/2}
taic
mu
rho
xi

if(interactive()){
postscript("comppr2.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(1979:1987,mu[1,],ylim=c(-2,2),xlab="Year",ylab="Hourly wage")
lines(1979:1987,mu[1,])
points(1979:1987,mu[2,],pch=2)
lines(1979:1987,mu[2,])
legend(1980,-1,legend=c("Europe","Others"),pch=c(1,2),bty="n")
dev.off()
}

# Multivariate ante-dependence

det <- function(x) abs(prod(diag(qr(x)$qr)))
s <- t(comp1-mean(comp1))%*%(comp1-mean(comp1))/10
t2 <- t1 <- matrix(1,ncol=10,nrow=10)
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):i)t1[i,j] <- t1[i,j]*s[k,k-1]
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):(i-1))t2[i,j] <- t2[i,j]*s[k,k]
for(i in 3:10)for(j in 1:(i-2)){
	s[i,j] <- t1[i,j]/t2[i,j]
	s[j,i] <- s[i,j]}
s
solve(s)
10*(10*(1+log(2*pi))+log(det(s)))/2+1+19

z <- glm(as.vector(t(comp1))~c(rep(0,60),rep(1,40)))
fitted <- matrix(z$fitted,ncol=10,byrow=T)
s <- t(comp1-fitted)%*%(comp1-fitted)/10
t2 <- t1 <- matrix(1,ncol=10,nrow=10)
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):i)t1[i,j] <- t1[i,j]*s[k,k-1]
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):(i-1))t2[i,j] <- t2[i,j]*s[k,k]
for(i in 3:10)for(j in 1:(i-2)){
	s[i,j] <- t1[i,j]/t2[i,j]
	s[j,i] <- s[i,j]}
s
solve(s)
10*(10*(1+log(2*pi))+log(det(s)))/2+2+19

output1 <- as.matrix(output)
z <- glm(as.vector(t(comp1))~as.vector(t(output1)))
fitted <- matrix(z$fitted,ncol=10,byrow=T)
s <- t(comp1-fitted)%*%(comp1-fitted)/10
t2 <- t1 <- matrix(1,ncol=10,nrow=10)
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):i)t1[i,j] <- t1[i,j]*s[k,k-1]
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):(i-1))t2[i,j] <- t2[i,j]*s[k,k]
for(i in 3:10)for(j in 1:(i-2)){
	s[i,j] <- t1[i,j]/t2[i,j]
	s[j,i] <- s[i,j]}
s
solve(s)
10*(10*(1+log(2*pi))+log(det(s)))/2+2+19

z <- glm(as.vector(t(comp1))~as.vector(t(output1))*c(rep(0,60),rep(1,40)))
fitted <- matrix(z$fitted,ncol=10,byrow=T)
s2 <- s <- t(comp1-fitted)%*%(comp1-fitted)/10
t2 <- t1 <- matrix(1,ncol=10,nrow=10)
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):i)t1[i,j] <- t1[i,j]*s[k,k-1]
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):(i-1))t2[i,j] <- t2[i,j]*s[k,k]
for(i in 3:10)for(j in 1:(i-2)){
	s[i,j] <- t1[i,j]/t2[i,j]
	s[j,i] <- s[i,j]}
s
solve(s)
10*(10*(1+log(2*pi))+log(det(s)))/2+4+19

z <- glm(as.vector(t(comp1))~gl(10,1,100))
fitted <- matrix(z$fitted,ncol=10,byrow=T)
s <- t(comp1-fitted)%*%(comp1-fitted)/10
t2 <- t1 <- matrix(1,ncol=10,nrow=10)
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):i)t1[i,j] <- t1[i,j]*s[k,k-1]
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):(i-1))t2[i,j] <- t2[i,j]*s[k,k]
for(i in 3:10)for(j in 1:(i-2)){
	s[i,j] <- t1[i,j]/t2[i,j]
	s[j,i] <- s[i,j]}
s
solve(s)
10*(10*(1+log(2*pi))+log(det(s)))/2+10+19

z <- glm(as.vector(t(comp1))~gl(10,1,100)*gl(2,60,100))
fitted <- matrix(z$fitted,ncol=10,byrow=T)
s <- t(comp1-fitted)%*%(comp1-fitted)/10
t2 <- t1 <- matrix(1,ncol=10,nrow=10)
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):i)t1[i,j] <- t1[i,j]*s[k,k-1]
for(i in 3:10)for(j in 1:(i-2))for(k in (j+1):(i-1))t2[i,j] <- t2[i,j]*s[k,k]
for(i in 3:10)for(j in 1:(i-2)){
	s[i,j] <- t1[i,j]/t2[i,j]
	s[j,i] <- s[i,j]}
s
solve(s)
10*(10*(1+log(2*pi))+log(det(s)))/2+20+19
s1 <- s
v1 <- sqrt(diag(s1))
for(i in 2:10)for(j in 1:(i-1))s1[i,j] <- s1[i,j]/v1[i]/v1[j]
s1

if(interactive()){
postscript("compprof.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(1978:1987,z$fit[1:10],ylim=c(0,20),xlab="Year",ylab="Hourly wage")
lines(1978:1987,z$fit[1:10])
points(1978:1987,z$fit[91:100],pch=2)
lines(1978:1987,z$fit[91:100])
legend(1979,18,legend=c("Europe","Others"),pch=c(1,2),bty="n")
dev.off()
}

s1 <- s
v1 <- sqrt(diag(s1))
for(i in 2:10)for(j in 1:(i-1))s1[i,j] <- s1[i,j]/v1[i]/v1[j]
s1
10*(10*(1+log(2*pi))+log(det(s2)))/2+4+55
