library(growth)
library(repeated)

cor <- as.matrix(read.table("coronary.dat",skip=5))
colnames(cor) <- c("1","3","5","7","9","11","13")
treat <- as.factor(c(rep(1,9),rep(2,10),rep(3,8),rep(4,9)))
reps <- rmna(restovec(cor,times=seq(1,13,by=2)),
	ccov=tcctomat(treat))

if(interactive()){
times <- seq(1,13,by=2)
postscript("coronary.eps",height=8)
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(reps,nind=1:9,ylim=c(0,6),xlab="",
	ylab="Coronary sinus potassium",main="A",lty=1,xaxt="n",yaxt="n")
axis(1,at=c(1,3,5,7,9,11,13))
axis(2,at=c(0,2,4,6))
plot(reps,nind=10:19,ylim=c(0,6),xlab="",
	ylab="",main="B",lty=1,xaxt="n",yaxt="n")
axis(1,at=c(1,3,5,7,9,11,13))
axis(2,at=c(0,2,4,6))
plot(reps,nind=20:27,ylim=c(0,6),xlab="Minutes",
	ylab="Coronary sinus potassium",main="C",lty=1,xaxt="n",yaxt="n")
axis(1,at=c(1,3,5,7,9,11,13))
axis(2,at=c(0,2,4,6))
plot(reps,nind=28:36,ylim=c(0,6),xlab="Minutes",
	ylab="",main="D",lty=1,xaxt="n",yaxt="n")
axis(1,at=c(1,3,5,7,9,11,13))
axis(2,at=c(0,2,4,6))
dev.off()
}

z <- glm(response(reps)~covariates(reps)[covind(reps)]
	*as.factor(times(reps)))

if(interactive()){
postscript("coron2.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,z$fit[1:7],ylim=c(0,6),xlab="Minutes",
	ylab="Coronary sinus potassium",xaxt="n",yaxt="n")
axis(1,at=c(1,3,5,7,9,11,13))
axis(2,at=c(0,2,4,6))
lines(times,z$fit[1:7])
points(times,z$fit[64:70],pch=2)
lines(times,z$fit[64:70])
points(times,z$fit[134:140],pch=3)
lines(times,z$fit[134:140])
points(times,z$fit[190:196],pch=4)
lines(times,z$fit[190:196])
legend(2,2.5,legend=c("A","B","C","D"),pch=1:4,bty="n")
dev.off()
}

fitted <- matrix(z$fitted,ncol=7,byrow=T)
s <- t(as.matrix(cor)-fitted)%*%(as.matrix(cor)-fitted)/36
s1 <- s
v1 <- sqrt(diag(s1))
for(i in 2:7)for(j in 1:(i-1))s1[i,j] <- s1[i,j]/v1[i]/v1[j]
s1

# no treatment effect
carma(reps)
carma(reps,torder=1)
carma(reps,torder=2)
carma(reps,torder=3)
carma(reps,torder=6)
carma(reps,pre=2,pos=c(1,1))
carma(reps,torder=1,pre=1,pos=c(1,1))
carma(reps,torder=2,pre=2,pos=c(1,1))
carma(reps,torder=3,pre=1,pos=c(1,1))
carma(reps,torder=6,pre=1,pos=c(1,1))
carma(reps,torder=1,pre=c(1,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,torder=2,pre=c(1.3,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,torder=3,pre=c(1,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,torder=6,pre=c(1,0.5),pos=rbind(c(1,1),c(2,2)))
carma(reps,arma=c(1,0,0),parma=-1)
carma(reps,torder=1,arma=c(1,0,0),parma=-1)
carma(reps,torder=2,arma=c(1,0,0),parma=-1)
carma(reps,torder=3,arma=c(1,0,0),parma=-1)
carma(reps,torder=6,arma=c(1,0,0),parma=-2)

# treatment effect
carma(reps,ccov=~treat)
carma(reps,ccov=~treat,torder=1)
carma(reps,ccov=~treat,torder=2)
carma(reps,ccov=~treat,torder=3)
carma(reps,ccov=~treat,torder=6)
carma(reps,ccov=~treat,pre=2,pos=c(1,1))
carma(reps,ccov=~treat,torder=1,pre=1,pos=c(1,1))
carma(reps,ccov=~treat,torder=2,pre=2,pos=c(1,1))
carma(reps,ccov=~treat,torder=3,pre=1.2,pos=c(1,1))
carma(reps,ccov=~treat,torder=6,pre=1,pos=c(1,1))
carma(reps,ccov=~treat,torder=1,pre=c(1.1,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=2,pre=c(1.3,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=3,pre=c(1.1,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=6,pre=c(1,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=1,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=2,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=3,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=6,arma=c(1,0,0),parma=-2)

# treatment x time interaction
carma(reps,ccov=~treat,torder=1,interact=c(1,1,1))
carma(reps,ccov=~treat,torder=2,interact=c(2,2,2))
carma(reps,ccov=~treat,torder=3,interact=c(3,3,3))
carma(reps,ccov=~treat,torder=6,interact=c(6,6,6))
carma(reps,ccov=~treat,torder=1,interact=c(1,1,1),pre=1,
	pos=c(1,1))
carma(reps,ccov=~treat,torder=2,interact=c(2,2,2),pre=2,
	pos=c(1,1))
carma(reps,ccov=~treat,torder=3,interact=c(3,3,3),pre=1.2,
	pos=c(1,1))
carma(reps,ccov=~treat,torder=6,interact=c(6,6,6),pre=1,
	pos=c(1,1))
carma(reps,ccov=~treat,torder=1,interact=c(1,1,1),
	pre=c(1,-0.5),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=2,interact=c(2,2,2),
	pre=c(1.5,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=3,interact=c(3,3,3),
	pre=c(1.1,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=6,interact=c(6,6,6),
	pre=c(1.1,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~treat,torder=1,interact=c(1,1,1),
	arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=2,interact=c(2,2,2),
	arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=3,interact=c(3,3,3),
	arma=c(1,0,0),parma=-1)
carma(reps,ccov=~treat,torder=6,interact=c(6,6,6),
	arma=c(1,0,0),parma=-2)

print(zn <- elliptic(reps,ccov=~treat,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.89))
elliptic(reps,ccov=~treat,torder=3,interact=c(3,3,3),
	preg=zn$beta,varfn=~times,pvar=c(-0.93,0.02),par=0.91,iter=200)

# Chapter 6
elliptic(reps,ccov=~treat,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.89)
elliptic(reps,ccov=~treat,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.89,dist="power exp",pell=1)
