library(growth)
library(repeated)

cor <- as.matrix(read.table("coronary.dat",skip=5))
colnames(cor) <- c("1","3","5","7","9","11","13")
tr2 <- c(rep(0,9),rep(1,10),rep(0,17))
tr3 <- c(rep(0,19),rep(1,8),rep(0,9))
tr4 <- c(rep(0,27),rep(1,9))
tr <- cbind(tr2,tr3,tr4)
colnames(tr) <- c("Tr2","Tr3","Tr4")
times <- seq(1,13,by=2)

if(interactive()){
postscript("coronary.eps",width=5,height=5)
par(mfrow=c(2,2),font.main=1)
plot(times,cor[1,],type="l",ylim=c(0,6),xlab="",
	ylab="Coronary sinus potassium",main="A")
for(i in 2:9)lines(times,cor[i,])
plot(times,cor[10,],type="l",ylim=c(0,6),xlab="",
	ylab="",main="B")
for(i in 11:19)lines(times,cor[i,])
plot(times,cor[20,],type="l",ylim=c(0,6),xlab="Minutes",
	ylab="Coronary sinus potassium",main="C")
for(i in 21:27)lines(times,cor[i,])
plot(times,cor[28,],type="l",ylim=c(0,6),xlab="Minutes",
	ylab="",main="D")
for(i in 29:36)lines(times,cor[i,])
}

y <- as.vector(t(cor))
treat <- as.factor(c(rep(1,63),rep(2,70),rep(3,56),rep(4,63)))
time <- gl(7,1,252)
z <- glm(y~treat*time)

if(interactive()){
postscript("coron2.eps",width=5,height=5)
plot(times,z$fit[1:7],ylim=c(0,6),xlab="Minutes",
	ylab="Coronary sinus potassium")
lines(times,z$fit[1:7])
points(times,z$fit[64:70],pch=2)
lines(times,z$fit[64:70])
points(times,z$fit[134:140],pch=3)
lines(times,z$fit[134:140])
points(times,z$fit[190:196],pch=4)
lines(times,z$fit[190:196])
legend(2,2.5,legend=c("A","B","C","D"),pch=1:4,bty="n")
}

fitted <- matrix(z$fitted,ncol=7,byrow=T)
s <- t(as.matrix(cor)-fitted)%*%(as.matrix(cor)-fitted)/36
s1 <- s
v1 <- sqrt(diag(s1))
for(i in 2:7)for(j in 1:(i-1))s1[i,j] <- s1[i,j]/v1[i]/v1[j]
s1

cor <- restovec(cor,times=times)
# no treatment effect
carma(cor)
kalseries(cor,preg=3,psh=0.6,intensity="normal",dep="independence")
carma(cor,torder=1)
kalseries(cor,preg=c(4,0),psh=0.6,intensity="normal",dep="independence",
	torder=1)
carma(cor,torder=2)
carma(cor,torder=3)
carma(cor,torder=6)
carma(cor,pre=2,pos=c(1,1))
kalseries(cor,preg=3.53,psh=0.1,intensity="normal",dep="frailty",pinit=2.5)
carma(cor,torder=1,pre=1,pos=c(1,1))
carma(cor,torder=2,pre=2,pos=c(1,1))
kalseries(cor,preg=c(3.59,0.0046,-0.0045),psh=0.1,intensity="normal",
	dep="frailty",pinit=2.1,torder=2)
carma(cor,torder=3,pre=1,pos=c(1,1))
carma(cor,torder=6,pre=1,pos=c(1,1))
carma(cor,torder=1,pre=c(1,1),pos=rbind(c(1,1),c(2,2)))
carma(cor,torder=2,pre=c(1.3,1),pos=rbind(c(1,1),c(2,2)))
carma(cor,torder=3,pre=c(1,1),pos=rbind(c(1,1),c(2,2)))
carma(cor,torder=6,pre=c(1,0.5),pos=rbind(c(1,1),c(2,2)))
carma(cor,arma=c(1,0,0),parma=-1)
kalseries(cor,preg=3.57,psh=0.081,intensity="normal",dep="serial",
	pinit=2.5,pdep=0.89)
carma(cor,torder=1,arma=c(1,0,0),parma=-1)
carma(cor,torder=2,arma=c(1,0,0),parma=-1)
kalseries(cor,preg=c(3.69,0.0035,-0.0053),psh=0.096,intensity="normal",
	dep="serial",pinit=2.48,pdep=0.8,torder=2)
carma(cor,torder=3,arma=c(1,0,0),parma=-1)
carma(cor,torder=6,arma=c(1,0,0),parma=-2)

# treatment effect
reps <- rmna(cor,ccov=tcctomat(tr))
carma(reps,ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(4,-1,-0.5,-0.7),psh=0.6,intensity="normal",
	dep="independence",ccov=~Tr2+Tr3+Tr4)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2)
kalseries(reps,preg=c(4,-1,-0.5,-0.7,0,0),psh=0.6,intensity="normal",
	dep="independence",torder=2,ccov=~Tr2+Tr3+Tr4)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6)
carma(reps,ccov=~Tr2+Tr3+Tr4,pre=2,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,pre=1,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,pre=2,pos=c(1,1))
kalseries(reps,preg=c(3.93,-0.5,-0.3,-0.31,0.008,-0.0034),psh=0.073,
	intensity="normal",dep="frailty",torder=2,pinit=1.7,ccov=~Tr2+Tr3+Tr4)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,pre=1.2,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,pre=1,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,pre=c(1.1,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,pre=c(1.3,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,pre=c(1.1,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,pre=c(1,1),
	pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,arma=c(1,0,0),parma=-1)
kalseries(reps,preg=c(3.92,-0.48,-0.26,-0.26,-0.002,-0.0036),psh=0.069,
	pdep=0.82,intensity="normal",dep="serial",torder=2,pinit=2.113,
	ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(4.1,-0.65,-0.45,-0.39,0.007,-0.0039),psh=0.07,
	pdep=0.69,intensity="normal",dep="Markov",torder=2,pinit=2.92,
	ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(4.2,-0.83,-0.56,-0.54,-0.003,-0.004),psh=0.7,pdep=0.85,
	intensity="logistic",dep="serial",torder=2,pinit=0.1,ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(1.6,-0.3,-0.2,-0.2,0,0),psh=5,pdep=0.999,dep="serial",
	intensity="Weibull",torder=2,pinit=0.01,link="log",ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(47,-20,-17,-14,-0.6,-0.2),psh=6,pdep=0.28,
	intensity="Weibull",dep="serial",torder=2,pinit=3.8,trans="exp",
	ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(2.5,0,0,0,0,0),psh=1,pdep=0.83,intensity="Weibull",
	dep="frailty",torder=2,pinit=1,link="log",ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(3.9,-0.5,-0.265,-0.26,-0.0022,-0.0036),psh=0.1,pdep=0.83,
	intensity="Cauchy",dep="serial",torder=2,pinit=2,ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(2.5,0,0,0,0,0),psh=1,pdep=0.83,intensity="log logistic",
	dep="serial",torder=2,pinit=1,ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(2.5,0,0,0,0,0),psh=1,pdep=0.83,intensity="log normal",
	dep="serial",torder=2,pinit=2,iter=200,ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(2,0,0,0,0,0),psh=1,pdep=0.83,inten="gamma",
	dep="serial",torder=2,pinit=1,link="log",iter=200,ccov=~Tr2+Tr3+Tr4)
kalseries(reps,preg=c(3.15,0.15,0.35,0.53,0,0),psh=0.016,pdep=0.89,
	intensity="Laplace",dep="serial",torder=2,pinit=2.51,ccov=~Tr2+Tr3+Tr4)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,arma=c(1,0,0),parma=-1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,arma=c(1,0,0),parma=-2)

# treatment x time interaction
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,interact=c(1,1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,interact=c(2,2,2))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,interact=c(6,6,6))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,interact=c(1,1,1),
	pre=1,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,interact=c(2,2,2),
	pre=2,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	pre=1.2,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,interact=c(6,6,6),
	pre=1,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,interact=c(1,1,1),
	pre=c(1,-0.5),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,interact=c(2,2,2),
	pre=c(1.5,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	pre=c(1.1,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,interact=c(6,6,6),
	pre=c(1.1,1),pos=rbind(c(1,1),c(2,2)))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=1,interact=c(1,1,1),
	arma=c(1,0,0),parma=-1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=2,interact=c(2,2,2),
	arma=c(1,0,0),parma=-1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	arma=c(1,0,0),parma=-1)
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=6,interact=c(6,6,6),
	arma=c(1,0,0),parma=-2)

time <- 2*codes(time)-1
shape <- function(p) p[1]+p[2]*time
print(z <- elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,
	interact=c(3,3,3),pvar=0.38,par=0.89))
elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.89,auto="gaussian")
elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.89,auto="cauchy")
elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.1,auto="spherical")
#elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
#	pvar=0.38,par=20,auto="IOU")
elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	preg=z$beta,pvar=c(-1.6,0.13),par=0.89,varfn=shape)
elliptic(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	pvar=0.38,par=0.89,pell=1)

carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	arma=c(2,0,0),parma=c(-1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	arma=c(1,0,0),parma=-1.5,pre=0.5,pos=c(1,1))
carma(reps,ccov=~Tr2+Tr3+Tr4,torder=3,interact=c(3,3,3),
	arma=c(1,0,0),parma=-1.5,pre=c(0.11,-0.1),pos=rbind(c(1,1),c(2,2)))
