library(growth)

lutein <- read.table("lutein.dat",skip=5)
attach(lutein)

if(interactive()){
postscript("lutein.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(seq(0,470,by=10),V1,type="l",ylim=c(0,10),xlab="Time (min)",
	ylab="Level of luteinizing hormone")
lines(seq(0,470,by=10),V2,lty=2)
lines(seq(0,470,by=10),V3,lty=3)
legend(150,10,legend=c("Cycle 1, late follcular phase",
	"Cycle 2, early follcular phase","Cycle 2, late follcular phase"),
	lty=1:3,bty="n")
dev.off()
postscript("lutper.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
}
z1 <- plot.pergram(V1,ylim=c(0,500))
z2 <- plot.pergram(V2,add=T,lty=2)
z3 <- plot.pergram(V3,add=T,lty=3)
legend(1,500,legend=c("Cycle 1, late follicular phase",
	"Cycle 2, early follicular phase","Cycle 2, late follicular phase"),
	lty=1:3,bty="n")
#plot.cum.pergram(V1)
#plot.cum.pergram(V2)
#plot.cum.pergram(V3)

if(interactive()){
dev.off()
postscript("lutspec.eps",height=7,width=5)
}
par(mfcol=c(3,1),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
sm1 <- NULL
for(i in 1:(dim(z1)[1]-2))sm1 <- c(sm1,sum(z1[i+(0:2),2])/3)
plot(z1[2:23,1],sm1,type="l",ylim=c(0,1000),xlim=c(0,3.6),xlab="",
	ylab="Estimated spectrum",main="Cycle 1, late follcular phase")
lines(z1[2:23,1],6*sm1/12.59,lty=3)
lines(z1[2:23,1],6*sm1/1.635,lty=3)
sm2 <- NULL
for(i in 1:(dim(z1)[1]-2))sm2 <- c(sm2,sum(z2[i+(0:2),2])/3)
plot(z1[2:23,1],sm2,type="l",ylim=c(0,1000),xlim=c(0,3.6),xlab="",
	ylab="Estimated spectrum",main="Cycle 2, early follcular phase")
lines(z1[2:23,1],6*sm2/12.59,lty=3)
lines(z1[2:23,1],6*sm2/1.635,lty=3)
sm3 <- NULL
for(i in 1:(dim(z1)[1]-2))sm3 <- c(sm3,sum(z3[i+(0:2),2])/3)
plot(z1[2:23,1],sm3,type="l",ylim=c(0,1000),xlim=c(0,3.6),xlab="Frequency",
	ylab="Estimated spectrum",main="Cycle 2, late follcular phase")
lines(z1[2:23,1],6*sm3/12.59,lty=3)
lines(z1[2:23,1],6*sm3/1.635,lty=3)
if(interactive()){
dev.off()
}

-sum(-c(z1[,2],z2[,2],z3[,2])/c(z1[,2],z2[,2],z3[,2])-
	log(c(z1[,2],z2[,2],z3[,2])))+72
print(u1 <- glm(c(z1[,2],z2[,2],z3[,2])~gl(24,1,72),family=Gamma(link=log)))
-sum(-c(z1[,2],z2[,2],z3[,2])/u1$fitted-log(u1$fitted))+24
print(u2 <- glm(c(z1[,2],z2[,2],z3[,2])~gl(24,1,72)+gl(3,24,72),
	family=Gamma(link=log)))
-sum(-c(z1[,2],z2[,2],z3[,2])/u2$fitted-log(u2$fitted))+26
lin <- 1:24
lin <- rep(lin-mean(lin),3)
print(u3 <- glm(c(z1[,2],z2[,2],z3[,2])~gl(24,1,72)+gl(3,24,72)*(lin+I(lin^2)),
	family=Gamma(link=log)))
-sum(-c(z1[,2],z2[,2],z3[,2])/u3$fitted-log(u3$fitted))+30
print(u2a <- glm(c(z1[,2],z2[,2],z3[,2])~gl(24,1,72)+I(gl(3,24,72)==2),
	family=Gamma(link=log)))
-sum(-c(z1[,2],z2[,2],z3[,2])/u2a$fitted-log(u2a$fitted))+25
print(u3a <- glm(c(z1[,2],z2[,2],z3[,2])~gl(24,1,72)+I(gl(3,24,72)==2)*
	(lin+I(lin^2)),family=Gamma(link=log)))
-sum(-c(z1[,2],z2[,2],z3[,2])/u3a$fitted-log(u3a$fitted))+29

-sum(-c(sm1,sm2,sm3)/c(sm1,sm2,sm3)-log(c(sm1,sm2,sm3)))+66
print(v1 <- glm(c(sm1,sm2,sm3)~gl(22,1,66),family=Gamma(link=log)))
-sum(-c(sm1,sm2,sm3)/v1$fit-log(v1$fit))+22
print(v2 <- glm(c(sm1,sm2,sm3)~gl(22,1,66)+gl(3,22,66),family=Gamma(link=log)))
-sum(-c(sm1,sm2,sm3)/v2$fit-log(v2$fit))+24
lin <- 1:22
lin <- rep(lin-mean(lin),3)
print(v3 <- glm(c(sm1,sm2,sm3)~gl(22,1,66)+gl(3,22,66)*(lin+I(lin^2)),
	family=Gamma(link=log)))
-sum(-c(sm1,sm2,sm3)/v3$fit-log(v3$fit))+28
print(v2a <- glm(c(sm1,sm2,sm3)~gl(22,1,66)+I(gl(3,22,66)==2),
	family=Gamma(link=log)))
-sum(-c(sm1,sm2,sm3)/v2a$fit-log(v2a$fit))+23
print(v3a <- glm(c(sm1,sm2,sm3)~gl(22,1,66)+I(gl(3,22,66)==2)*(lin+I(lin^2)),
	family=Gamma(link=log)))
-sum(-c(sm1,sm2,sm3)/v3a$fit-log(v3a$fit))+27
